==============================================================================
Credits
==============================================================================

Maintainers
------------------------------------------------------------------------------

* Andreas Schuderer <pypi@schuderer.net>

Contributors
------------------------------------------------------------------------------

* Elisa Partodikromo <https://github.com/planeetjupyter>
* Gosia Rorat <https://github.com/gosiarorat>
* Bart Driessen <https://github.com/Bart92>
* Bob Platte <https://github.com/bobplatte>

Apache License 2.0

Documentation: https://mllaunchpad.readthedocs.io.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
